@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Provide musical cadence chords
 
-our $VERSION = '0.0406';
+our $VERSION = '0.0500';
 
 use Moo;
 use Music::Chord::Note;
@@ -32,6 +32,12 @@ has octave => (
 );
 
 
+has format => (
+    is      => 'ro',
+    default => sub { '' },
+);
+
+
 sub cadence {
     my ( $self, %args ) = @_;
 
@@ -57,32 +63,32 @@ sub cadence {
     );
 
     if ( $args{type} eq 'perfect' ) {
-        my $chord = _generate_chord( $args{scale}, $scale[4], $args{octave}, $mtr, $mcn );
+        my $chord = $self->_generate_chord( $args{scale}, $scale[4], $args{octave}, $mtr, $mcn );
         push @$cadence, $chord;
 
-        $chord = _generate_chord( $args{scale}, $scale[0], $args{octave}, $mtr, $mcn );
+        $chord = $self->_generate_chord( $args{scale}, $scale[0], $args{octave}, $mtr, $mcn );
         push @$cadence, $chord;
     }
     elsif ( $args{type} eq 'plagal' ) {
-        my $chord = _generate_chord( $args{scale}, $scale[3], $args{octave}, $mtr, $mcn );
+        my $chord = $self->_generate_chord( $args{scale}, $scale[3], $args{octave}, $mtr, $mcn );
         push @$cadence, $chord;
 
-        $chord = _generate_chord( $args{scale}, $scale[0], $args{octave}, $mtr, $mcn );
+        $chord = $self->_generate_chord( $args{scale}, $scale[0], $args{octave}, $mtr, $mcn );
         push @$cadence, $chord;
     }
     elsif ( $args{type} eq 'half' ) {
-        my $chord = _generate_chord( $args{scale}, $scale[ $args{leading} - 1 ], $args{octave}, $mtr, $mcn );
+        my $chord = $self->_generate_chord( $args{scale}, $scale[ $args{leading} - 1 ], $args{octave}, $mtr, $mcn );
         push @$cadence, $chord;
 
-        $chord = _generate_chord( $args{scale}, $scale[4], $args{octave}, $mtr, $mcn );
+        $chord = $self->_generate_chord( $args{scale}, $scale[4], $args{octave}, $mtr, $mcn );
         push @$cadence, $chord;
     }
     elsif ( $args{type} eq 'deceptive' ) {
-        my $chord = _generate_chord( $args{scale}, $scale[4], $args{octave}, $mtr, $mcn );
+        my $chord = $self->_generate_chord( $args{scale}, $scale[4], $args{octave}, $mtr, $mcn );
         push @$cadence, $chord;
 
         my $note = $args{variation} == 1 ? $scale[5] : $scale[3];
-        $chord = _generate_chord( $args{scale}, $note, $args{octave}, $mtr, $mcn );
+        $chord = $self->_generate_chord( $args{scale}, $note, $args{octave}, $mtr, $mcn );
         push @$cadence, $chord;
     }
     else {
@@ -93,7 +99,7 @@ sub cadence {
 }
 
 sub _generate_chord {
-    my ( $scale, $note, $octave, $mtr, $mcn ) = @_;
+    my ( $self, $scale, $note, $octave, $mtr, $mcn ) = @_;
 
     # Know what chords should be diminished
     my %diminished = (
@@ -117,6 +123,13 @@ sub _generate_chord {
     # Generate the chord notes
     my @notes = $mcn->chord( $note . $type );
 
+    if ( $self->format eq 'midi' ) {
+        for ( @notes ) {
+            s/#/s/;
+            s/b/f/;
+        }
+    }
+
     # Append the octave if requested
     @notes = map { $_ . $octave } @notes
         if $octave;
@@ -138,7 +151,7 @@ Music::Cadence - Provide musical cadence chords
 
 =head1 VERSION
 
-version 0.0406
+version 0.0500
 
 =head1 SYNOPSIS
 
@@ -146,11 +159,7 @@ version 0.0406
 
   my $mc = Music::Cadence->new;
 
-  $mc = Music::Cadence->new(
-    key    => 'C',
-    scale  => 'major',
-    octave => 4,
-  );
+  $mc = Music::Cadence->new( octave => 4 );
 
   my $chords = $mc->cadence( type => 'perfect' );
   # [['G4','B4','D4'], ['C4','E4','G4']]
@@ -161,6 +170,15 @@ version 0.0406
     octave  => 0,
   ); # [['D','F','A'], ['G','B','D']]
 
+  $mc = Music::Cadence->new(
+    key    => 'C#',
+    octave => 5,
+    format => 'midi',
+  );
+
+  my $chords = $mc->cadence( type => 'perfect' );
+  # [['Gs5','C5','Ds5'], ['Cs5','F5','Gs5']]
+
 =head1 DESCRIPTION
 
 C<Music::Cadence> provides musical cadence chords.
@@ -195,6 +213,11 @@ Supported scales are:
 The octave to append to chord notes.  Default: C<0> meaning "do not
 append."
 
+=head2 format
+
+If C<midi>, convert sharp C<#> to C<s> and C<b> to C<f> after chord
+generation.  Default: C<''> (none)
+
 =head1 METHODS
 
 =head2 new
@@ -205,6 +228,7 @@ append."
     key    => $key,
     scale  => $scale,
     octave => $octave,
+    format => $format,
   );
 
 Create a new C<Music::Cadence> object.
